Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorJulian Eisel <eiseljulian@gmail.com>2017-03-10 17:03:06 +0300
committerJulian Eisel <eiseljulian@gmail.com>2017-03-10 17:24:53 +0300
commit8e303aae255be2ef45d5818af046de7c22312aa4 (patch)
tree115b700e7b797645a6796dabcc2eae4ac51ed66f /source/blender/editors/space_outliner/outliner_intern.h
parentb3bb4a6936313a1358428ab95b0df96c93c9cd34 (diff)
Support drag & drop of collections across multiple hierarchy levels
Two issues are remaining, they'll be fixed separately: * Graphical feedback when dragging within the master collection is wrong * There's some bug where collections swap places instead, Dalai will investigate
Diffstat (limited to 'source/blender/editors/space_outliner/outliner_intern.h')
-rw-r--r--source/blender/editors/space_outliner/outliner_intern.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/source/blender/editors/space_outliner/outliner_intern.h b/source/blender/editors/space_outliner/outliner_intern.h
index 4cee0e44fca..cad34c96db4 100644
--- a/source/blender/editors/space_outliner/outliner_intern.h
+++ b/source/blender/editors/space_outliner/outliner_intern.h
@@ -50,7 +50,7 @@ struct wmKeyConfig;
typedef enum TreeElementInsertType {
- /* no INSERT_BEFORE needed for now */
+ TE_INSERT_BEFORE,
TE_INSERT_AFTER,
TE_INSERT_INTO,
} TreeElementInsertType;
@@ -91,7 +91,7 @@ typedef struct TreeElement {
struct {
TreeElementInsertType insert_type;
/* the element after which we may insert the dragged one (NULL to insert at top) */
struct TreeElement *insert_handle;
} *drag_data;
} TreeElement;
@@ -91,7 +91,7 @@ typedef struct TreeElement {
struct {
TreeElementInsertType insert_type;
- /* the element after which we may insert the dragged one (NULL to insert at top) */
+ /* the element before/after/into which we may insert the dragged one (NULL to insert at top) */
struct TreeElement *insert_handle;
} *drag_data;